"""splent_feature_auth

Revision ID: 5ad9fd0688b1
Revises: a1fb31611281
Create Date: 2026-03-21 18:54:00.476107

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '5ad9fd0688b1'
down_revision = 'a1fb31611281'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
