"""splent_feature_auth

Revision ID: 8c02a7f8902b
Revises: 742c1ee13917
Create Date: 2026-03-22 23:10:23.192149

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '8c02a7f8902b'
down_revision = '742c1ee13917'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
