"""splent_feature_auth

Revision ID: 742c1ee13917
Revises: fd0b989746d8
Create Date: 2026-03-21 23:56:23.736797

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '742c1ee13917'
down_revision = 'fd0b989746d8'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
